@@ -1,6 +1,6 @@
 import sys
 
-from slai_cli.main import main
+# from slai_cli.main import main
 
 
 if __name__ == "__main__":
