@@ -46,12 +46,12 @@ def requires_slai_project(callback):
 
         if not slai_directory_present:
             log.warn(
-                "No project detected in this directory, create one with 'slai create <project_name>'."  # noqa
+                "No project detected in this directory, create one with 'slai init <project_name>'."  # noqa
             )
             return
         elif slai_directory_present and not Path(".slai/config.yml").exists():
             log.warn(
-                "No project detected in this directory, create one with 'slai create <project_name>'."  # noqa
+                "No project detected in this directory, create one with 'slai init <project_name>'."  # noqa
             )
             return
 
