@@ -12,7 +12,7 @@ from slai_cli.model import commands as model
 from slai_cli.profile import commands as profile
 from slai_cli.decorators import requires_slai_credentials
 from slai_cli.errors import handle_error
-from slai_cli import get_version, version
+from slai_cli import get_version, version, bundle
 
 
 def with_profile(f):
@@ -51,14 +51,15 @@ def main():
     entry_point.add_command(model.model)
     entry_point.add_command(profile.profile)
     entry_point.add_command(version)
+    entry_point.add_command(bundle)
 
     try:
         entry_point()
     except HTTPError:
         handle_error(error_msg="unknown_http_error")
-        return 1
+        sys.exit(1)
 
-    return 0
+    sys.exit(0)
 
 
 if __name__ == "__main__":
